@@ -4,6 +4,8 @@ describe 'heat::db::sync' do
 
   shared_examples_for 'heat-dbsync' do
 
+    it { is_expected.to contain_class('heat::deps') }
+
     it 'runs heat-manage db_sync' do
       is_expected.to contain_exec('heat-dbsync').with(
         :command     => 'heat-manage --config-file /etc/heat/heat.conf db_sync',
@@ -17,6 +19,7 @@ describe 'heat::db::sync' do
                          'Anchor[heat::config::end]',
                          'Anchor[heat::dbsync::begin]'],
         :notify      => 'Anchor[heat::dbsync::end]',
+        :tag         => 'openstack-db',
       )
     end
 
@@ -40,6 +43,7 @@ describe 'heat::db::sync' do
                            'Anchor[heat::config::end]',
                            'Anchor[heat::dbsync::begin]'],
           :notify      => 'Anchor[heat::dbsync::end]',
+          :tag         => 'openstack-db',
         )
         }
       end
